# -*- coding: utf-8 -*-
from setuphelpers import *
import time

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""

def install():

    # Uninstalling older versions of the software
    for to_uninstall in installed_softwares(name="EShare"):
        if Version(to_uninstall["version"]) < Version(control.get_software_version()):
            print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
            killalltasks(ensure_list(control.impacted_process))
            run(uninstall_cmd(to_uninstall["key"]))
            wait_uninstallkey_absent(to_uninstall["key"])
            if isdir(to_uninstall["install_location"]):
                remove_tree(to_uninstall["install_location"])
    # Cherche le fichier MSI correspondant
    msi_files = glob.glob('EShareClient_*.msi')
    
    if not msi_files:
        raise Exception("Fichier MSI non trouvé. Veuillez vérifier que le fichier 'EShareClient_*.msi' est présent dans le dossier.")

    bin_name = msi_files[0]

    # Installer le package MSI
    install_msi_if_needed(bin_name)

def uninstall():
    # Liste des exécutables de désinstallation avec leurs arguments silencieux
    uninstallers = [
        (r'C:\Program Files (x86)\EShare Audio\uninst.exe', '/S'),
        (r'C:\Program Files (x86)\EShare Camera\uninst.exe', '/S'),
        (r'C:\Program Files (x86)\ESystemRemoteService\uninst.exe', '/S'),
        (r'MsiExec.exe', '/X{17BEDB35-68B7-412C-9536-00973562B77A}', '/qn')
    ]
    
    # Désinstaller chaque composant
    for uninstaller in uninstallers:
        command = f'"{uninstaller[0]}" {" ".join(uninstaller[1:])}'
        
        if os.path.exists(uninstaller[0]) or "MsiExec.exe" in uninstaller[0]:
            print(f"Exécution de la désinstallation : {command}")
            try:
                run(command, accept_returncodes=[0, 3010])
                # Attendre un moment pour s'assurer que la désinstallation est terminée
                time.sleep(10)  # Augmenté le temps d'attente pour permettre aux désinstallateurs de terminer
            except Exception as e:
                print(f"Erreur lors de l'exécution de la commande : {e}")
        else:
            print(f"Chemin non trouvé pour la désinstallation : {uninstaller[0]}")

    # Vérifier si les répertoires existent encore et les supprimer si nécessaire
    remove_tree(r'C:\Program Files (x86)\EShare Audio', ignore_errors=True)
    remove_tree(r'C:\Program Files (x86)\EShare Camera', ignore_errors=True)
    remove_tree(r'C:\Program Files (x86)\ESystemRemoteService', ignore_errors=True)

    # Supprimer les entrées de registre résiduelles, le cas échéant
    try:
        reg_delete_key(HKEY_LOCAL_MACHINE, r'SOFTWARE\EShare Audio')
        reg_delete_key(HKEY_LOCAL_MACHINE, r'SOFTWARE\EShare Camera')
        reg_delete_key(HKEY_LOCAL_MACHINE, r'SOFTWARE\ESystemRemoteService')
    except Exception as e:
        print(f"Erreur lors de la suppression des clés de registre : {e}")
    